@@ -1,16 +1,26 @@
 # frozen_string_literal: true
 
 module TTFunk
+  # Data-fork suitcases resource file
   class ResourceFile
+    # Resource map
+    #
+    # @return [Hash]
     attr_reader :map
 
+    # Open a resource file
+    #
+    # @param path [String, Pathname]
+    # @yieldparam resource_file [TTFunk::ResourceFile]
+    # @return [any] result of the block
     def self.open(path)
-      ::File.open(path, 'rb') do |io|
+      ::File.open(path, 'rb') { |io|
         file = new(io)
-        yield file
-      end
+        yield(file)
+      }
     end
 
+    # @param io [IO]
     def initialize(io)
       @io = io
 
@@ -41,7 +51,7 @@ module TTFunk
               id: id,
               attributes: attr,
               offset: data_ofs,
-              handle: handle
+              handle: handle,
             }
 
             if name_list_offset + name_ofs < map_offset + map_length
@@ -58,6 +68,16 @@ module TTFunk
       end
     end
 
+    # Get resource
+    #
+    # @overload [](type, index = 0)
+    #   @param type [String]
+    #   @param inxed [Integer]
+    #   @return [String]
+    # @overload [](type, name)
+    #   @param type [String]
+    #   @param name [String]
+    #   @return [String]
     def [](type, index = 0)
       if @map[type]
         collection = index.is_a?(Integer) ? :list : :named
@@ -70,8 +90,12 @@ module TTFunk
       end
     end
 
+    # Get resource names
+    #
+    # @param type [String]
+    # @return [Array<String>]
     def resources_for(type)
-      (@map[type] && @map[type][:named] || {}).keys
+      ((@map[type] && @map[type][:named]) || {}).keys
     end
 
     private
