@@ -4,15 +4,27 @@ require_relative '../table'
 
 module TTFunk
   class Table
+    # Kerning (`kern`) table
     class Kern < Table
+      # Table version
+      # @return [Integer]
       attr_reader :version
+
+      # Subtables.
+      # @return [Array<TTFunk::Table::Kern::Format0>]
       attr_reader :tables
 
+      # Encode table.
+      #
+      # @param kerning [TTFunk::Table::Kern]
+      # @param mapping [Hash{Integer => Integer}] keys are new glyph IDs, values
+      #   are old glyph IDs
+      # @return [String, nil]
       def self.encode(kerning, mapping)
-        return nil unless kerning.exists? && kerning.tables.any?
+        return unless kerning.exists? && kerning.tables.any?
 
-        tables = kerning.tables.map { |table| table.recode(mapping) }.compact
-        return nil if tables.empty?
+        tables = kerning.tables.filter_map { |table| table.recode(mapping) }
+        return if tables.empty?
 
         [0, tables.length, tables.join].pack('nnA*')
       end
@@ -52,11 +64,11 @@ module TTFunk
           version: version,
           length: length,
           coverage: coverage,
-          data: raw[10..-1],
-          vertical: (coverage & 0x1 == 0),
+          data: raw[10..],
+          vertical: (coverage & 0x1).zero?,
           minimum: (coverage & 0x2 != 0),
           cross: (coverage & 0x4 != 0),
-          override: (coverage & 0x8 != 0)
+          override: (coverage & 0x8 != 0),
         )
       end
 
@@ -73,13 +85,13 @@ module TTFunk
             data: io.read(length - 8),
             vertical: (coverage & 0x8000 != 0),
             cross: (coverage & 0x4000 != 0),
-            variation: (coverage & 0x2000 != 0)
+            variation: (coverage & 0x2000 != 0),
           )
         end
       end
 
       def add_table(format, attributes = {})
-        if format == 0
+        if format.zero?
           @tables << Kern::Format0.new(attributes)
         end
         # Unsupported kerning tables are silently ignored
