@@ -4,22 +4,27 @@ require_relative '../table'
 
 module TTFunk
   class Table
+    # Index to Location table.
     class Loca < Table
+      # Glyph ofsets
+      # @return [Array<Integer>]
       attr_reader :offsets
 
-      # Accepts an array of offsets, with each index corresponding to the
-      # glyph id with that index.
+      # Encode table.
       #
-      # Returns a hash containing:
-      #
-      # * :table - the string representing the table's contents
-      # * :type  - the type of offset (to be encoded in the 'head' table)
+      # @param offsets [Array<Integer>] an array of offsets, with each index
+      #   corresponding to the glyph id with that index.
+      # @return [Hash] result hash:
+      #   * `:type` - the type of offset (to be encoded in the 'head' table):
+      #     * `0` - short offsets
+      #     * `1` - long offsets
+      #   * `:table` - encoded bytes
       def self.encode(offsets)
         long_offsets =
-          offsets.any? do |offset|
+          offsets.any? { |offset|
             short_offset = offset / 2
             short_offset * 2 != offset || short_offset > 0xffff
-          end
+          }
 
         if long_offsets
           { type: 1, table: offsets.pack('N*') }
@@ -28,10 +33,18 @@ module TTFunk
         end
       end
 
+      # Glyph offset by ID.
+      #
+      # @param glyph_id [Integer]
+      # @return [Integer] - offset of the glyph in the `glyf` table
       def index_of(glyph_id)
         @offsets[glyph_id]
       end
 
+      # Size of encoded glyph.
+      #
+      # @param glyph_id [Integer]
+      # @return [Integer]
       def size_of(glyph_id)
         @offsets[glyph_id + 1] - @offsets[glyph_id]
       end
