@@ -8,6 +8,5 @@ require 'rspec'
 Dir[File.expand_path('support/**/*.rb', __dir__)].sort.each { |f| require f }
 
 RSpec.configure do |config|
-  config.include PathHelpers
-  config.include TextHelpers
+  config.include(PathHelpers)
 end
